@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2021-09-07 19:19:55
+@LastEditTime: 2021-09-13 18:14:51
 @LastEditors: HuangJianYi
 :description: 用户处理
 """
@@ -507,6 +507,60 @@ class GetHorseRaceLampListHandler(SevenBaseHandler):
         return self.reponse_json_success(page_list)
 
 
+class PropLogListHandler(SevenBaseHandler):
+    """
+    :description: 道具数量变动明细记录
+    """
+    @filter_check_params("act_id")
+    def get_async(self):
+        """
+        :description: 道具数量变动明细记录
+        :param page_index：页索引
+        :param page_size：页大小
+        :param act_id：活动id
+        :param nick_name：淘宝名
+        :param start_date：开始时间
+        :param end_date：结束时间
+        :param user_open_id：用户open_id
+        :return list
+        :last_editors: HuangJianYi
+        """
+        page_index = int(self.get_param("page_index", 0))
+        page_size = int(self.get_param("page_size", 20))
+        act_id = int(self.get_param("act_id", 0))
+        change_type = int(self.get_param("change_type", 0))
+        user_nick = self.get_param("nick_name")
+        start_date = self.get_param("start_date")
+        end_date = self.get_param("end_date")
+        user_open_id = self.get_param("user_open_id")
+
+        condition = "act_id=%s"
+        params = [act_id]
+        field = "user_nick,change_type,operate_type,prop_type,machine_name,specs_type,operate_value,history_value,title,create_date"
+
+        if user_open_id:
+            condition += " AND open_id=%s"
+            params.append(user_open_id)
+        if user_nick:
+            condition += " AND user_nick=%s"
+            params.append(user_nick)
+        if start_date:
+            condition += " AND create_date>=%s"
+            params.append(start_date)
+        if end_date:
+            condition += " AND create_date<=%s"
+            params.append(end_date)
+        if change_type > 0:
+            condition += " AND change_type=%s"
+            params.append(change_type)
+
+        page_list, total = PropLogModel(context=self).get_dict_page_list(field, page_index, page_size, condition, order_by="id desc", params=params)
+
+        page_info = PageInfo(page_index, page_size, total, page_list)
+
+        self.reponse_json_success(page_info)
+
+
 class GivePropHandler(SevenBaseHandler):
     """
     :description:道具卡赠送
@@ -568,7 +622,7 @@ class GivePropHandler(SevenBaseHandler):
         if prop_type == 3:
             if user_detail.tips_card_count <= 0:
                 return self.reponse_json_error("Error", "提示卡数量不足")
-            if prop_give_total >= exchange_info.day_limit:
+            if prop_give_total >= exchange_info.day_limit and exchange_info.day_limit >0:
                 return self.reponse_json_error("Error", "提示卡赠送数量达到上限")
             history_value = user_detail.tips_card_count
             update_sql = "tips_card_count=tips_card_count-1"
